@@ -245,7 +245,7 @@ static int cpbuilder_internal_cleancow(const struct pbuilderconfig* pc)
 {
   printf(" -> Cleaning COW directory\n");
 
-  if (0!=rmrf_check_mount(pc->buildplace))
+  if (!pc->debug && 0!=rmrf_check_mount(pc->buildplace))
     return 1;
   return 0;
 }
@@ -350,6 +350,10 @@ int cpbuilder_build(const struct pbuilderconfig* pc, const char* dscfile_)
     {
       PBUILDER_ADD_PARAM("--binary-arch");
     }
+  else if (pc->binary_indep)
+    {
+      PBUILDER_ADD_PARAM("--binary-indep");
+    }
   PBUILDER_ADD_PARAM("--no-targz");
   PBUILDER_ADD_PARAM("--internal-chrootexec");
   PBUILDER_ADD_PARAM(buf_chroot);
@@ -412,7 +416,7 @@ out:
   if (ret)
     {
       printf("pbuilder create failed\n");
-      if (0!=rmrf_check_mount(pc->basepath))
+      if (!pc->debug && 0!=rmrf_check_mount(pc->basepath))
 	{
 	  fprintf(stderr, "Could not remove original tree\n");
 	}
@@ -673,7 +677,7 @@ int cpbuilder_update(const struct pbuilderconfig* pc)
 	      fprintf(stderr, "E: could not update with cowdancer, try --no-cowdancer-update option\n");
 	    }
 
-	  if (0!=rmrf_check_mount(pc->buildplace))
+	  if (!pc->debug && 0!=rmrf_check_mount(pc->buildplace))
 	    {
 	      fprintf(stderr, "Could not remove original tree\n");
 	    }
